@@ -21,8 +21,10 @@ from LbAPLocal.cli import main
 
 @pytest.fixture
 def with_mock_run_local(mocker):
+    mocker.patch("LbAPLocal.cli.do_options_parsing", side_effect=lambda *a: [])
+
     mocker.patch(
-        "LbAPLocal.cern_sso.get_with_cookies",
+        "LbAPCommon.cern_sso.get_with_cookies",
         side_effect=lambda x: {
             "dynamic_options": {
                 "local_autoconf.py": (
@@ -62,7 +64,7 @@ def with_mock_run_local(mocker):
 def test_run_test_stripping(with_proxy, data_pkg_repo, with_data, with_mock_run_local):
     runner = CliRunner()
     result = runner.invoke(main, ["test", "cbtesting", "MC_2011_MagUp_Lb2Lee_strip"])
-    assert result.exit_code == 0
+    assert result.exit_code == 0, result.stdout
 
     assert "Application Manager Finalized successfully" in result.stdout
     assert "Application Manager Terminated successfully" in result.stdout
@@ -93,7 +95,7 @@ def test_run_test_stripping(with_proxy, data_pkg_repo, with_data, with_mock_run_
 @pytest.fixture
 def with_mock_reproduce(mocker, with_data):
     mocker.patch(
-        "LbAPLocal.cern_sso.get_with_cookies",
+        "LbAPCommon.cern_sso.get_with_cookies",
         side_effect=lambda x: {
             "command": [
                 "gaudirun.py",
@@ -212,7 +214,7 @@ def test_reproduce(with_proxy, with_data, mocker, with_mock_reproduce):
     result = runner.invoke(
         main, ["reproduce", "1920001", "Lb2Lll", "MC_2011_MagUp_Lb2Lee_strip", "0"]
     )
-    assert result.exit_code == 0
+    assert result.exit_code == 0, result.stdout
     assert "Cloning " in result.stdout
     assert "Downloading pool_xml_catalog.xml" in result.stdout
     assert "Downloading prodConf_DaVinci_00012345_00006789_1.py" in result.stdout
